.. documentation master file, created by
   sphinx-quickstart on Mon Apr  3 15:37:35 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Developer documents
===================

Contents
--------

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Getting started <setup>
